Documentation
¶
Overview ¶
Package discogs provides a client for interacting with the Discogs API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicInformation ¶
type BasicInformation struct {
Artists []Artist `json:"artists"`
Title string `json:"title"`
Year int `json:"year"`
}
BasicInformation contains the core details about a release.
type Client ¶
type Client struct {
LegacyClient discogs.Discogs // For existing collection/search calls
HTTPClient *http.Client
Token string
}
Client manages requests to the Discogs API, including the wantlist.
func (*Client) WantlistRequest ¶
WantlistRequest performs a raw HTTP request to a given Discogs API endpoint. It is used for wantlist operations not covered by the legacy client.
type Want ¶
type Want struct {
ID int `json:"id"`
BasicInformation BasicInformation `json:"basic_information"`
}
Want represents a single item in the user's wantlist.
Click to show internal directories.
Click to hide internal directories.